pub enum PrikkError {
CanonicalEncoding(String),
InvalidObjectId(String),
InvalidSignature(String),
InvalidName(String),
ObjectTypeMismatch {
expected: String,
actual: String,
},
UnsupportedFormatVersion(u32),
MalformedData(String),
Integrity(String),
LockConflict(String),
UnsupportedObjectType(String),
Io(String),
}Expand description
Error type used by the initial implementation crates.
Variants
CanonicalEncoding(String)
Canonical encoding failed because input data violates the frozen schema contract.
InvalidObjectId(String)
An object identifier had an invalid form.
InvalidSignature(String)
A signature had an invalid form or did not match its envelope context.
InvalidName(String)
A path-like name failed Prikk path/ref validation.
ObjectTypeMismatch
A persistent object had an unexpected type.
Fields
UnsupportedFormatVersion(u32)
The persistent format version is unsupported.
MalformedData(String)
A persisted object or record has malformed bytes.
Integrity(String)
A persisted object was found at a path that does not match its computed ID.
LockConflict(String)
A lock could not be acquired because another writer may be active.
UnsupportedObjectType(String)
The requested object type cannot be persisted in the requested store.
Io(String)
Placeholder for I/O errors without making this crate depend on std::io::Error in variants.